
Notes for developers
----------


Git workflow
====

    git pull
    git commit
    git push


Testing
===

    nosetests --with-coverage --cover-html --cover-package=lisa

Code climate
===

    pep8


